<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\FormModel;

use Zend\Form\Annotation;

/**
 * @Annotation\Name("passwordchange")
 * @Annotation\Hydrator("Zend\Hydrator\ClassMethods")
 */
class PasswordChangeModel
{
    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Password")
     * @Annotation\Required({"required":"true"})
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Validator({
     *     "name":"StringLength", "options":{
     *          "min":8, "max":255,
     *          "messages": {
     *              "stringLengthTooShort": "error_password_length",
     *              "stringLengthTooLong": "error_password_length"
     *          }
     *     }
     * })
     * @Annotation\Validator({
     *     "name": "Regex", "options": {
     *          "pattern": "/(?:.*[0-9].*[^\w].*|.*[^\w].*[0-9].*)/",
     *          "messages": {
     *              "regexNotMatch": "error_password_pattern"
     *          }
     *      }
     * })
     * @Annotation\Validator({
     *     "name": "Identical", "options": {
     *          "strict": false,
     *          "token": "passwordConfirmation",
     *          "messages": {"notSame": "error_password_confirmation"}
     *     }
     * })
     * @Annotation\Options({"label": "label_password"})
     */
    protected $password;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Password")
     * @Annotation\Required({"required":"true"})
     * @Annotation\AllowEmpty()
     * @Annotation\Options({"label": "label_password_confirmation"})
     */
    protected $passwordConfirmation;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Submit")
     * @Annotation\Attributes({"value": "label_submit"})
     */
    protected $submit;

    /**
     * @return string
     */
    public function getPassword(): string
    {
        return $this->password;
    }

    /**
     * @param string $password
     */
    public function setPassword(string $password): void
    {
        $this->password = $password;
    }

    /**
     * @return string
     */
    public function getPasswordConfirmation(): string
    {
        return $this->passwordConfirmation;
    }

    /**
     * @param string $passwordConfirmation
     */
    public function setPasswordConfirmation(string $passwordConfirmation): void
    {
        $this->passwordConfirmation = $passwordConfirmation;
    }

    /**
     * @return string
     */
    public function getSubmit(): string
    {
        return $this->submit;
    }

    /**
     * @param string $submit
     */
    public function setSubmit(string $submit): void
    {
        $this->submit = $submit;
    }
}
