<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\FormModel;

use Zend\Form\Annotation;

/**
 * @Annotation\Name("passwordreset")
 * @Annotation\Hydrator("Zend\Hydrator\ClassMethods")
 */
class PasswordResetModel
{
    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Email")
     * @Annotation\Required({"required":"true"})
     * @Annotation\Filter({"name": "StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min": 1, "max": 255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\EmailAddress"})
     * @Annotation\Options({"label": "label_username"})
     */
    protected $username;


    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Submit")
     * @Annotation\Attributes({"value": "label_submit"})
     */
    protected $submit;

    /**
     * @return string
     */
    public function getUsername(): string
    {
        return $this->username;
    }

    /**
     * @param string $username
     */
    public function setUsername(string $username): void
    {
        $this->username = $username;
    }

    /**
     * @return string
     */
    public function getSubmit(): string
    {
        return $this->submit;
    }

    /**
     * @param string $submit
     */
    public function setSubmit(string $submit): void
    {
        $this->submit = $submit;
    }
}
