<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\FormModel;

use Zend\Form\Annotation;

/**
 * @Annotation\Name("user_init")
 * @Annotation\Hydrator("Zend\Hydrator\ClassMethods")
 */
class UserInitModel
{
    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Email")
     * @Annotation\Required(true)
     * @Annotation\Filter({"name": "StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min": 1, "max": 255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\EmailAddress"})
     * @Annotation\Options({"label": "label_username"})
     */
    protected $username;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(true)
     * @Annotation\Validator({
     *     "name": "Zend\Validator\Identical",
     *     "options": {
     *         "strict": false,
     *         "token": "username",
     *         "messages": { "notSame": "error_username_confirmation" }
     *     }
     * })
     * @Annotation\Options({"label": "label_username_confirmation"})
     */
    protected $usernameConfirmation;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(true)
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min": 1, "max": 255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\NotEmpty"})
     * @Annotation\Validator({
     *     "name": "Regex",
     *     "options": {"pattern": "/^\D*$/"}
     * })
     * @Annotation\Options({"label": "label_firstname"})
     */
    protected $firstname;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(true)
     * @Annotation\Filter({"name": "StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min":1, "max":255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\NotEmpty"})
     * @Annotation\Validator({
     *     "name": "Regex",
     *     "options": {"pattern":"/^\D*$/"}
     * })
     * @Annotation\Options({"label": "label_lastname"})
     */
    protected $lastname;

    /**
     * @var bool
     * @Annotation\Type("Zend\Form\Element\Checkbox")
     * @Annotation\Required(true)
     * @Annotation\Validator({"name":"NotEmpty"})
     * @Annotation\Filter({"name": "Boolean"})
     * @Annotation\Validator({
     *     "name": "Identical", "options": {
     *          "token": true,
     *          "messages": {"notSame": "error_eula_accepted"}
     *     }
     * })
     */
    protected $eulaAccepted;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Submit")
     * @Annotation\Attributes({"value": "label_submit"})
     */
    protected $submit;

    /**
     * @return string
     */
    public function getUsername(): string
    {
        return $this->username;
    }

    /**
     * @param string $username
     */
    public function setUsername(string $username): void
    {
        $this->username = $username;
    }

    /**
     * @return string
     */
    public function getUsernameConfirmation(): string
    {
        return $this->usernameConfirmation;
    }

    /**
     * @param string $usernameConfirmation
     */
    public function setUsernameConfirmation(string $usernameConfirmation): void
    {
        $this->usernameConfirmation = $usernameConfirmation;
    }

    /**
     * @return string
     */
    public function getFirstname(): string
    {
        return $this->firstname;
    }

    /**
     * @param string $firstname
     */
    public function setFirstname(string $firstname): void
    {
        $this->firstname = $firstname;
    }

    /**
     * @return string
     */
    public function getLastname(): string
    {
        return $this->lastname;
    }

    /**
     * @param string $lastname
     */
    public function setLastname(string $lastname): void
    {
        $this->lastname = $lastname;
    }

    /**
     * @return bool
     */
    public function isEulaAccepted(): bool
    {
        return $this->eulaAccepted;
    }

    /**
     * @param bool $eulaAccepted
     */
    public function setEulaAccepted(bool $eulaAccepted): void
    {
        $this->eulaAccepted = $eulaAccepted;
    }

    /**
     * @return string
     */
    public function getSubmit(): string
    {
        return $this->submit;
    }

    /**
     * @param string $submit
     */
    public function setSubmit(string $submit): void
    {
        $this->submit = $submit;
    }
}
