<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\FormModel;

use Zend\Form\Annotation;

/**
 * @Annotation\Name("user_update")
 * @Annotation\Hydrator("Zend\Hydrator\ClassMethods")
 */
class UserUpdateModel
{
    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Select")
     * @Annotation\Required(false)
     * @Annotation\Options({
     *     "label": "label_salutation",
     *     "empty_option": "",
     *     "options":{
     *          {"value": "mr", "label": "label_salutation_mr"},
     *          {"value": "mrs", "label": "label_salutation_mrs"}
     *     }
     * })
     */
    protected $salutation;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(false)
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Options({"label": "label_academic_title"})
     */
    protected $academicTitle;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(true)
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min": 1, "max": 255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\NotEmpty"})
     * @Annotation\Validator({
     *     "name": "Regex",
     *     "options": {"pattern": "/^\D*$/"}
     * })
     * @Annotation\Options({"label": "label_firstname"})
     */
    protected $firstname;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(true)
     * @Annotation\Filter({"name": "StringTrim"})
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min":1, "max":255}
     * })
     * @Annotation\Validator({"name": "Zend\Validator\NotEmpty"})
     * @Annotation\Validator({
     *     "name": "Regex",
     *     "options": {"pattern":"/^\D*$/"}
     * })
     * @Annotation\Options({"label": "label_lastname"})
     */
    protected $lastname;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Select")
     * @Annotation\Required(true)
     * @Annotation\Validator({
     *     "name": "StringLength",
     *     "options": {"min":1, "max":255}
     * })
     * @Annotation\Options({
     *     "label": "label_home_library",
     *     "disable_inarray_validator": true,
     *     "empty_option": ""
     * })
     */
    protected $homeLibrary;

    /**
     * @var int|null
     * @Annotation\Type("Zend\Form\Element\Number")
     * @Annotation\Required(false)
     * @Annotation\Attributes({"min": 1900, "max": 2018})
     * @Annotation\Options({"label": "label_year_of_birth"})
     * @Annotation\Filter({"name": "ToNull"})
     * @Annotation\Filter({"name": "ToInt"})
     */
    protected $yearOfBirth;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Required(false)
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Options({"label": "label_job_title"})
     */
    protected $jobTitle;

    /**
     * @var string
     * @Annotation\Type("Zend\Form\Element\Text")
     * @Annotation\Filter({"name":"StringTrim"})
     * @Annotation\Required(false)
     * @Annotation\Options({"label": "label_college"})
     */
    protected $college;

    /**
     * @var string|null
     * @Annotation\Type("Zend\Form\Element\Submit")
     * @Annotation\Attributes({"value": "label_submit"})
     */
    protected $submit;

    /**
     * @return string
     */
    public function getSalutation(): ?string
    {
        return $this->salutation;
    }

    /**
     * @param string $salutation
     */
    public function setSalutation(string $salutation): void
    {
        $this->salutation = $salutation;
    }

    /**
     * @return string|null
     */
    public function getAcademicTitle(): ?string
    {
        return $this->academicTitle;
    }

    /**
     * @param string $academicTitle
     */
    public function setAcademicTitle(string $academicTitle): void
    {
        $this->academicTitle = $academicTitle;
    }

    /**
     * @return string
     */
    public function getFirstname(): string
    {
        return $this->firstname;
    }

    /**
     * @param string $firstname
     */
    public function setFirstname(string $firstname): void
    {
        $this->firstname = $firstname;
    }

    /**
     * @return string
     */
    public function getLastname(): string
    {
        return $this->lastname;
    }

    /**
     * @param string $lastname
     */
    public function setLastname(string $lastname): void
    {
        $this->lastname = $lastname;
    }

    /**
     * @return string
     */
    public function getHomeLibrary(): string
    {
        return $this->homeLibrary;
    }

    /**
     * @param string $homeLibrary
     */
    public function setHomeLibrary(string $homeLibrary): void
    {
        $this->homeLibrary = $homeLibrary;
    }

    /**
     * @return int|null
     */
    public function getYearOfBirth(): ?int
    {
        return $this->yearOfBirth;
    }

    /**
     * @param int|null $yearOfBirth
     */
    public function setYearOfBirth(?int $yearOfBirth): void
    {
        $this->yearOfBirth = $yearOfBirth;
    }

    /**
     * @return string
     */
    public function getJobTitle(): string
    {
        return $this->jobTitle;
    }

    /**
     * @param string $jobTitle
     */
    public function setJobTitle(string $jobTitle): void
    {
        $this->jobTitle = $jobTitle;
    }

    /**
     * @return string
     */
    public function getCollege(): string
    {
        return $this->college;
    }

    /**
     * @param string $college
     */
    public function setCollege(string $college): void
    {
        $this->college = $college;
    }

    /**
     * @return string|null
     */
    public function getSubmit(): ?string
    {
        return $this->submit;
    }

    /**
     * @param string|null $submit
     */
    public function setSubmit(?string $submit): void
    {
        $this->submit = $submit;
    }
}
