<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\VuFind\Auth;

use fid\Service\Client;
use fid\Service\ClientException;

class ILSAuthenticator
{
    /**
     * @var Client
     */
    protected $client;

    public function __construct(Client $client)
    {
        $this->client = $client;
    }

    /**
     * @return array|null
     * @throws ClientException
     */
    public function storedCatalogLogin()
    {
        $user = $this->client->requestUserDetails();

        if (!$user) {
            return null;
        }

        $data = [
            'username'  => $user->getUsername(),
            'firstname' => $user->getFirstname(),
            'lastname'  => $user->getLastname(),
            'email'     => $user->getUsername()
        ];

        if ($address = $user->getAddresses()[0] ?? null) {
            $data['address1'] = implode(' ', array_filter([
                $address->getLine1() . ',',
                $address->getZip(),
                $address->getCity() . ',',
                $address->getCountry()
            ]));
        }

        return $data;
    }

}